#[non_exhaustive]pub struct Cluster {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub state: State,
pub management: bool,
pub autoscaling_settings: Option<AutoscalingSettings>,
pub uid: String,
pub node_type_configs: HashMap<String, NodeTypeConfig>,
pub stretched_cluster_config: Option<StretchedClusterConfig>,
/* private fields */
}Expand description
A cluster in a private cloud.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of this cluster.
Resource names are schemeless URIs that follow the conventions in
https://cloud.google.com/apis/design/resource_names.
For example:
projects/my-project/locations/us-central1-a/privateClouds/my-cloud/clusters/my-cluster
create_time: Option<Timestamp>Output only. Creation time of this resource.
update_time: Option<Timestamp>Output only. Last update time of this resource.
state: StateOutput only. State of the resource.
management: boolOutput only. True if the cluster is a management cluster; false otherwise. There can only be one management cluster in a private cloud and it has to be the first one.
autoscaling_settings: Option<AutoscalingSettings>Optional. Configuration of the autoscaling applied to this cluster.
uid: StringOutput only. System-generated unique identifier for the resource.
node_type_configs: HashMap<String, NodeTypeConfig>Required. The map of cluster node types in this cluster, where the key is
canonical identifier of the node type (corresponds to the NodeType).
stretched_cluster_config: Option<StretchedClusterConfig>Optional. Configuration of a stretched cluster. Required for clusters that belong to a STRETCHED private cloud.
Implementations
Sourceimpl Cluster
impl Cluster
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Cluster::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Cluster::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Cluster::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Cluster::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Cluster::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Cluster::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_management<T: Into<bool>>(self, v: T) -> Self
pub fn set_management<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_autoscaling_settings<T>(self, v: T) -> Selfwhere
T: Into<AutoscalingSettings>,
pub fn set_autoscaling_settings<T>(self, v: T) -> Selfwhere
T: Into<AutoscalingSettings>,
Sets the value of autoscaling_settings.
Example
use google_cloud_vmwareengine_v1::model::AutoscalingSettings;
let x = Cluster::new().set_autoscaling_settings(AutoscalingSettings::default()/* use setters */);Sourcepub fn set_or_clear_autoscaling_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<AutoscalingSettings>,
pub fn set_or_clear_autoscaling_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<AutoscalingSettings>,
Sets or clears the value of autoscaling_settings.
Example
use google_cloud_vmwareengine_v1::model::AutoscalingSettings;
let x = Cluster::new().set_or_clear_autoscaling_settings(Some(AutoscalingSettings::default()/* use setters */));
let x = Cluster::new().set_or_clear_autoscaling_settings(None::<AutoscalingSettings>);Sourcepub fn set_node_type_configs<T, K, V>(self, v: T) -> Self
pub fn set_node_type_configs<T, K, V>(self, v: T) -> Self
Sets the value of node_type_configs.
Example
use google_cloud_vmwareengine_v1::model::NodeTypeConfig;
let x = Cluster::new().set_node_type_configs([
("key0", NodeTypeConfig::default()/* use setters */),
("key1", NodeTypeConfig::default()/* use (different) setters */),
]);Sourcepub fn set_stretched_cluster_config<T>(self, v: T) -> Selfwhere
T: Into<StretchedClusterConfig>,
pub fn set_stretched_cluster_config<T>(self, v: T) -> Selfwhere
T: Into<StretchedClusterConfig>,
Sets the value of stretched_cluster_config.
Example
use google_cloud_vmwareengine_v1::model::StretchedClusterConfig;
let x = Cluster::new().set_stretched_cluster_config(StretchedClusterConfig::default()/* use setters */);Sourcepub fn set_or_clear_stretched_cluster_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<StretchedClusterConfig>,
pub fn set_or_clear_stretched_cluster_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<StretchedClusterConfig>,
Sets or clears the value of stretched_cluster_config.
Example
use google_cloud_vmwareengine_v1::model::StretchedClusterConfig;
let x = Cluster::new().set_or_clear_stretched_cluster_config(Some(StretchedClusterConfig::default()/* use setters */));
let x = Cluster::new().set_or_clear_stretched_cluster_config(None::<StretchedClusterConfig>);Trait Implementations
impl StructuralPartialEq for Cluster