#[non_exhaustive]pub struct CreateClusterRequest {
pub parent: String,
pub cluster_id: String,
pub cluster: Option<Cluster>,
pub request_id: String,
pub validate_only: bool,
/* private fields */
}Expand description
Request message for VmwareEngine.CreateCluster
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the private cloud to create a new cluster
in. Resource names are schemeless URIs that follow the conventions in
https://cloud.google.com/apis/design/resource_names.
For example:
projects/my-project/locations/us-central1-a/privateClouds/my-cloud
cluster_id: StringRequired. The user-provided identifier of the new Cluster.
This identifier must be unique among clusters within the parent and becomes
the final token in the name URI.
The identifier must meet the following requirements:
- Only contains 1-63 alphanumeric characters and hyphens
- Begins with an alphabetical character
- Ends with a non-hyphen character
- Not formatted as a UUID
- Complies with RFC 1034 (section 3.5)
cluster: Option<Cluster>Required. The initial description of the new cluster.
request_id: StringOptional. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
validate_only: boolOptional. True if you want the request to be validated and not executed; false otherwise.
Implementations
Sourceimpl CreateClusterRequest
impl CreateClusterRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_cluster_id<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster_id<T: Into<String>>(self, v: T) -> Self
Sets the value of cluster_id.
Example
let x = CreateClusterRequest::new().set_cluster_id("example");Sourcepub fn set_cluster<T>(self, v: T) -> Self
pub fn set_cluster<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_cluster<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cluster<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateClusterRequest::new().set_request_id("example");Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateClusterRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateClusterRequest
impl Clone for CreateClusterRequest
Sourcefn clone(&self) -> CreateClusterRequest
fn clone(&self) -> CreateClusterRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateClusterRequest
impl Debug for CreateClusterRequest
Sourceimpl Default for CreateClusterRequest
impl Default for CreateClusterRequest
Sourcefn default() -> CreateClusterRequest
fn default() -> CreateClusterRequest
Sourceimpl Message for CreateClusterRequest
impl Message for CreateClusterRequest
Sourceimpl PartialEq for CreateClusterRequest
impl PartialEq for CreateClusterRequest
impl StructuralPartialEq for CreateClusterRequest