#[non_exhaustive]pub struct DeletePrivateCloudRequest {
pub name: String,
pub request_id: String,
pub force: bool,
pub delay_hours: Option<i32>,
/* private fields */
}Expand description
Request message for VmwareEngine.DeletePrivateCloud
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the private cloud to delete.
Resource names are schemeless URIs that follow the conventions in
https://cloud.google.com/apis/design/resource_names.
For example:
projects/my-project/locations/us-central1-a/privateClouds/my-cloud
request_id: StringOptional. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
force: boolOptional. If set to true, cascade delete is enabled and all children of this private cloud resource are also deleted. When this flag is set to false, the private cloud will not be deleted if there are any children other than the management cluster. The management cluster is always deleted.
delay_hours: Option<i32>Optional. Time delay of the deletion specified in hours. The default value
is 3. Specifying a non-zero value for this field changes the value of
PrivateCloud.state to DELETED and sets expire_time to the planned
deletion time. Deletion can be cancelled before expire_time elapses using
VmwareEngine.UndeletePrivateCloud.
Specifying a value of 0 for this field instead begins the deletion
process and ceases billing immediately. During the final deletion process,
the value of PrivateCloud.state becomes PURGING.
Implementations
Sourceimpl DeletePrivateCloudRequest
impl DeletePrivateCloudRequest
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = DeletePrivateCloudRequest::new().set_request_id("example");Sourcepub fn set_delay_hours<T>(self, v: T) -> Self
pub fn set_delay_hours<T>(self, v: T) -> Self
Sets the value of delay_hours.
Example
let x = DeletePrivateCloudRequest::new().set_delay_hours(42);Sourcepub fn set_or_clear_delay_hours<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delay_hours<T>(self, v: Option<T>) -> Self
Sets or clears the value of delay_hours.
Example
let x = DeletePrivateCloudRequest::new().set_or_clear_delay_hours(Some(42));
let x = DeletePrivateCloudRequest::new().set_or_clear_delay_hours(None::<i32>);Trait Implementations
Sourceimpl Clone for DeletePrivateCloudRequest
impl Clone for DeletePrivateCloudRequest
Sourcefn clone(&self) -> DeletePrivateCloudRequest
fn clone(&self) -> DeletePrivateCloudRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DeletePrivateCloudRequest
impl Debug for DeletePrivateCloudRequest
Sourceimpl Default for DeletePrivateCloudRequest
impl Default for DeletePrivateCloudRequest
Sourcefn default() -> DeletePrivateCloudRequest
fn default() -> DeletePrivateCloudRequest
Sourceimpl Message for DeletePrivateCloudRequest
impl Message for DeletePrivateCloudRequest
impl StructuralPartialEq for DeletePrivateCloudRequest