#[non_exhaustive]pub struct FetchNetworkPolicyExternalAddressesRequest {
pub network_policy: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for VmwareEngine.FetchNetworkPolicyExternalAddresses
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.network_policy: StringRequired. The resource name of the network policy to query for assigned
external IP addresses. Resource names are schemeless URIs that follow the
conventions in https://cloud.google.com/apis/design/resource_names. For
example:
projects/my-project/locations/us-central1/networkPolicies/my-policy
page_size: i32The maximum number of external IP addresses to return in one page. The service may return fewer than this value. The maximum value is coerced to 1000. The default value of this field is 500.
page_token: StringA page token, received from a previous
FetchNetworkPolicyExternalAddresses call. Provide this to retrieve the
subsequent page.
When paginating, all parameters provided to
FetchNetworkPolicyExternalAddresses, except for page_size and
page_token, must match the call that provided the page token.
Implementations
Sourceimpl FetchNetworkPolicyExternalAddressesRequest
impl FetchNetworkPolicyExternalAddressesRequest
Sourcepub fn set_network_policy<T: Into<String>>(self, v: T) -> Self
pub fn set_network_policy<T: Into<String>>(self, v: T) -> Self
Sets the value of network_policy.
Example
let x = FetchNetworkPolicyExternalAddressesRequest::new().set_network_policy(format!("projects/{project_id}/locations/{location_id}/networkPolicies/{network_policy_id}"));Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = FetchNetworkPolicyExternalAddressesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for FetchNetworkPolicyExternalAddressesRequest
impl Clone for FetchNetworkPolicyExternalAddressesRequest
Sourcefn clone(&self) -> FetchNetworkPolicyExternalAddressesRequest
fn clone(&self) -> FetchNetworkPolicyExternalAddressesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for FetchNetworkPolicyExternalAddressesRequest
impl Default for FetchNetworkPolicyExternalAddressesRequest
Sourcefn default() -> FetchNetworkPolicyExternalAddressesRequest
fn default() -> FetchNetworkPolicyExternalAddressesRequest
impl StructuralPartialEq for FetchNetworkPolicyExternalAddressesRequest