#[non_exhaustive]pub struct FetchNetworkPolicyExternalAddressesResponse {
pub external_addresses: Vec<ExternalAddress>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for VmwareEngine.FetchNetworkPolicyExternalAddresses
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.external_addresses: Vec<ExternalAddress>A list of external IP addresses assigned to VMware workload VMs within the scope of the given network policy.
next_page_token: StringA token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Implementations
Sourceimpl FetchNetworkPolicyExternalAddressesResponse
impl FetchNetworkPolicyExternalAddressesResponse
Sourcepub fn set_external_addresses<T, V>(self, v: T) -> Self
pub fn set_external_addresses<T, V>(self, v: T) -> Self
Sets the value of external_addresses.
Example
ⓘ
use google_cloud_vmwareengine_v1::model::ExternalAddress;
let x = FetchNetworkPolicyExternalAddressesResponse::new()
.set_external_addresses([
ExternalAddress::default()/* use setters */,
ExternalAddress::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = FetchNetworkPolicyExternalAddressesResponse::new().set_next_page_token("example");Trait Implementations
impl StructuralPartialEq for FetchNetworkPolicyExternalAddressesResponse