#[non_exhaustive]pub struct ListPeeringRoutesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request message for VmwareEngine.ListPeeringRoutes
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the network peering to retrieve peering
routes from. Resource names are schemeless URIs that follow the conventions
in https://cloud.google.com/apis/design/resource_names. For example:
projects/my-project/locations/global/networkPeerings/my-peering
page_size: i32The maximum number of peering routes to return in one page. The service may return fewer than this value. The maximum value is coerced to 1000. The default value of this field is 500.
page_token: StringA page token, received from a previous ListPeeringRoutes call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListPeeringRoutes must
match the call that provided the page token.
filter: StringA filter expression that matches resources returned in the response.
Currently, only filtering on the direction field is supported. To return
routes imported from the peer network, provide “direction=INCOMING”. To
return routes exported from the VMware Engine network, provide
“direction=OUTGOING”. Other filter expressions return an error.
Implementations
Sourceimpl ListPeeringRoutesRequest
impl ListPeeringRoutesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListPeeringRoutesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListPeeringRoutesRequest
impl Clone for ListPeeringRoutesRequest
Sourcefn clone(&self) -> ListPeeringRoutesRequest
fn clone(&self) -> ListPeeringRoutesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListPeeringRoutesRequest
impl Debug for ListPeeringRoutesRequest
Sourceimpl Default for ListPeeringRoutesRequest
impl Default for ListPeeringRoutesRequest
Sourcefn default() -> ListPeeringRoutesRequest
fn default() -> ListPeeringRoutesRequest
Sourceimpl Message for ListPeeringRoutesRequest
impl Message for ListPeeringRoutesRequest
Sourceimpl PartialEq for ListPeeringRoutesRequest
impl PartialEq for ListPeeringRoutesRequest
impl StructuralPartialEq for ListPeeringRoutesRequest