#[non_exhaustive]pub struct ListPrivateConnectionPeeringRoutesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for VmwareEngine.ListPrivateConnectionPeeringRoutes
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the private connection to retrieve peering
routes from. Resource names are schemeless URIs that follow the conventions
in https://cloud.google.com/apis/design/resource_names. For example:
projects/my-project/locations/us-west1/privateConnections/my-connection
page_size: i32The maximum number of peering routes to return in one page. The service may return fewer than this value. The maximum value is coerced to 1000. The default value of this field is 500.
page_token: StringA page token, received from a previous ListPrivateConnectionPeeringRoutes
call. Provide this to retrieve the subsequent page. When paginating, all
other parameters provided to ListPrivateConnectionPeeringRoutes must
match the call that provided the page token.
Implementations
Sourceimpl ListPrivateConnectionPeeringRoutesRequest
impl ListPrivateConnectionPeeringRoutesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListPrivateConnectionPeeringRoutesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListPrivateConnectionPeeringRoutesRequest
impl Clone for ListPrivateConnectionPeeringRoutesRequest
Sourcefn clone(&self) -> ListPrivateConnectionPeeringRoutesRequest
fn clone(&self) -> ListPrivateConnectionPeeringRoutesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ListPrivateConnectionPeeringRoutesRequest
impl Default for ListPrivateConnectionPeeringRoutesRequest
Sourcefn default() -> ListPrivateConnectionPeeringRoutesRequest
fn default() -> ListPrivateConnectionPeeringRoutesRequest
impl StructuralPartialEq for ListPrivateConnectionPeeringRoutesRequest