#[non_exhaustive]pub struct ListVmwareEngineNetworksRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
Request message for VmwareEngine.ListVmwareEngineNetworks
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the location to query for
VMware Engine networks. Resource names are schemeless URIs that follow the
conventions in https://cloud.google.com/apis/design/resource_names. For
example: projects/my-project/locations/global
page_size: i32The maximum number of results to return in one page. The maximum value is coerced to 1000. The default value of this field is 500.
page_token: StringA page token, received from a previous ListVmwareEngineNetworks call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
ListVmwareEngineNetworks must match the call that provided the page
token.
filter: StringA filter expression that matches resources returned in the response.
The expression must specify the field name, a comparison
operator, and the value that you want to use for filtering. The value
must be a string, a number, or a boolean. The comparison operator
must be =, !=, >, or <.
For example, if you are filtering a list of network peerings, you can
exclude the ones named example-network by specifying
name != "example-network".
To filter on multiple expressions, provide each separate expression within parentheses. For example:
(name = "example-network")
(createTime > "2021-04-12T08:15:10.40Z")By default, each expression is an AND expression. However, you
can include AND and OR expressions explicitly.
For example:
(name = "example-network-1") AND
(createTime > "2021-04-12T08:15:10.40Z") OR
(name = "example-network-2")order_by: StringSorts list results by a certain order. By default, returned results
are ordered by name in ascending order.
You can also sort results in descending order based on the name value
using orderBy="name desc".
Currently, only ordering by name is supported.
Implementations
Sourceimpl ListVmwareEngineNetworksRequest
impl ListVmwareEngineNetworksRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListVmwareEngineNetworksRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self