#[non_exhaustive]pub struct LoggingServer {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub hostname: String,
pub port: i32,
pub protocol: Protocol,
pub source_type: SourceType,
pub uid: String,
/* private fields */
}Expand description
Logging server to receive vCenter or ESXi logs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of this logging server.
Resource names are schemeless URIs that follow the conventions in
https://cloud.google.com/apis/design/resource_names.
For example:
projects/my-project/locations/us-central1-a/privateClouds/my-cloud/loggingServers/my-logging-server
create_time: Option<Timestamp>Output only. Creation time of this resource.
update_time: Option<Timestamp>Output only. Last update time of this resource.
hostname: StringRequired. Fully-qualified domain name (FQDN) or IP Address of the logging server.
port: i32Required. Port number at which the logging server receives logs.
protocol: ProtocolRequired. Protocol used by vCenter to send logs to a logging server.
source_type: SourceTypeRequired. The type of component that produces logs that will be forwarded to this logging server.
uid: StringOutput only. System-generated unique identifier for the resource.
Implementations
Sourceimpl LoggingServer
impl LoggingServer
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = LoggingServer::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = LoggingServer::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = LoggingServer::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = LoggingServer::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = LoggingServer::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = LoggingServer::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_hostname<T: Into<String>>(self, v: T) -> Self
pub fn set_hostname<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_protocol<T: Into<Protocol>>(self, v: T) -> Self
pub fn set_protocol<T: Into<Protocol>>(self, v: T) -> Self
Sourcepub fn set_source_type<T: Into<SourceType>>(self, v: T) -> Self
pub fn set_source_type<T: Into<SourceType>>(self, v: T) -> Self
Sets the value of source_type.
Example
use google_cloud_vmwareengine_v1::model::logging_server::SourceType;
let x0 = LoggingServer::new().set_source_type(SourceType::Esxi);
let x1 = LoggingServer::new().set_source_type(SourceType::Vcsa);Trait Implementations
Sourceimpl Clone for LoggingServer
impl Clone for LoggingServer
Sourcefn clone(&self) -> LoggingServer
fn clone(&self) -> LoggingServer
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for LoggingServer
impl Debug for LoggingServer
Sourceimpl Default for LoggingServer
impl Default for LoggingServer
Sourcefn default() -> LoggingServer
fn default() -> LoggingServer
Sourceimpl Message for LoggingServer
impl Message for LoggingServer
Sourceimpl PartialEq for LoggingServer
impl PartialEq for LoggingServer
impl StructuralPartialEq for LoggingServer