#[non_exhaustive]pub struct NetworkConfig {
pub management_cidr: String,
pub vmware_engine_network: String,
pub vmware_engine_network_canonical: String,
pub management_ip_address_layout_version: i32,
pub dns_server_ip: String,
/* private fields */
}Expand description
Network configuration in the consumer project with which the peering has to be done.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.management_cidr: StringRequired. Management CIDR used by VMware management appliances.
vmware_engine_network: StringOptional. The relative resource name of the VMware Engine network attached
to the private cloud. Specify the name in the following form:
projects/{project}/locations/{location}/vmwareEngineNetworks/{vmware_engine_network_id}
where {project} can either be a project number or a project ID.
vmware_engine_network_canonical: StringOutput only. The canonical name of the VMware Engine network in the form:
projects/{project_number}/locations/{location}/vmwareEngineNetworks/{vmware_engine_network_id}
management_ip_address_layout_version: i32Output only. The IP address layout version of the management IP address range. Possible versions include:
managementIpAddressLayoutVersion=1: Indicates the legacy IP address layout used by some existing private clouds. This is no longer supported for new private clouds as it does not support all features.managementIpAddressLayoutVersion=2: Indicates the latest IP address layout used by all newly created private clouds. This version supports all current features.
dns_server_ip: StringOutput only. DNS Server IP of the Private Cloud. All DNS queries can be forwarded to this address for name resolution of Private Cloud’s management entities like vCenter, NSX-T Manager and ESXi hosts.
Implementations
Sourceimpl NetworkConfig
impl NetworkConfig
Sourcepub fn set_management_cidr<T: Into<String>>(self, v: T) -> Self
pub fn set_management_cidr<T: Into<String>>(self, v: T) -> Self
Sets the value of management_cidr.
Example
let x = NetworkConfig::new().set_management_cidr("example");Sourcepub fn set_vmware_engine_network<T: Into<String>>(self, v: T) -> Self
pub fn set_vmware_engine_network<T: Into<String>>(self, v: T) -> Self
Sets the value of vmware_engine_network.
Example
let x = NetworkConfig::new().set_vmware_engine_network(format!("projects/{project_id}/locations/{location_id}/vmwareEngineNetworks/{vmware_engine_network_id}"));Sourcepub fn set_vmware_engine_network_canonical<T: Into<String>>(self, v: T) -> Self
pub fn set_vmware_engine_network_canonical<T: Into<String>>(self, v: T) -> Self
Sets the value of vmware_engine_network_canonical.
Example
let x = NetworkConfig::new().set_vmware_engine_network_canonical(format!("projects/{project_id}/locations/{location_id}/vmwareEngineNetworks/{vmware_engine_network_id}"));Sourcepub fn set_management_ip_address_layout_version<T: Into<i32>>(
self,
v: T,
) -> Self
pub fn set_management_ip_address_layout_version<T: Into<i32>>( self, v: T, ) -> Self
Sets the value of management_ip_address_layout_version.
Example
let x = NetworkConfig::new().set_management_ip_address_layout_version(42);Sourcepub fn set_dns_server_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_dns_server_ip<T: Into<String>>(self, v: T) -> Self
Sets the value of dns_server_ip.
Example
let x = NetworkConfig::new().set_dns_server_ip("example");Trait Implementations
Sourceimpl Clone for NetworkConfig
impl Clone for NetworkConfig
Sourcefn clone(&self) -> NetworkConfig
fn clone(&self) -> NetworkConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for NetworkConfig
impl Debug for NetworkConfig
Sourceimpl Default for NetworkConfig
impl Default for NetworkConfig
Sourcefn default() -> NetworkConfig
fn default() -> NetworkConfig
Sourceimpl Message for NetworkConfig
impl Message for NetworkConfig
Sourceimpl PartialEq for NetworkConfig
impl PartialEq for NetworkConfig
impl StructuralPartialEq for NetworkConfig