#[non_exhaustive]pub struct NetworkPeering {Show 16 fields
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub peer_network: String,
pub export_custom_routes: Option<bool>,
pub import_custom_routes: Option<bool>,
pub exchange_subnet_routes: Option<bool>,
pub export_custom_routes_with_public_ip: Option<bool>,
pub import_custom_routes_with_public_ip: Option<bool>,
pub state: State,
pub state_details: String,
pub peer_mtu: i32,
pub peer_network_type: PeerNetworkType,
pub uid: String,
pub vmware_engine_network: String,
pub description: String,
/* private fields */
}Expand description
Details of a network peering.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of the network peering. NetworkPeering is a
global resource and location can only be global. Resource names are
scheme-less URIs that follow the conventions in
https://cloud.google.com/apis/design/resource_names.
For example:
projects/my-project/locations/global/networkPeerings/my-peering
create_time: Option<Timestamp>Output only. Creation time of this resource.
update_time: Option<Timestamp>Output only. Last update time of this resource.
peer_network: StringRequired. The relative resource name of the network to peer with
a standard VMware Engine network. The provided network can be a
consumer VPC network or another standard VMware Engine network. If the
peer_network_type is VMWARE_ENGINE_NETWORK, specify the name in the form:
projects/{project}/locations/global/vmwareEngineNetworks/{vmware_engine_network_id}.
Otherwise specify the name in the form:
projects/{project}/global/networks/{network_id}, where
{project} can either be a project number or a project ID.
export_custom_routes: Option<bool>Optional. True if custom routes are exported to the peered network; false otherwise. The default value is true.
import_custom_routes: Option<bool>Optional. True if custom routes are imported from the peered network; false otherwise. The default value is true.
exchange_subnet_routes: Option<bool>Optional. True if full mesh connectivity is created and managed automatically between peered networks; false otherwise. Currently this field is always true because Google Compute Engine automatically creates and manages subnetwork routes between two VPC networks when peering state is ‘ACTIVE’.
export_custom_routes_with_public_ip: Option<bool>Optional. True if all subnet routes with a public IP address range are exported; false otherwise. The default value is true. IPv4 special-use ranges (https://en.wikipedia.org/wiki/IPv4#Special_addresses) are always exported to peers and are not controlled by this field.
import_custom_routes_with_public_ip: Option<bool>Optional. True if all subnet routes with public IP address range are imported; false otherwise. The default value is true. IPv4 special-use ranges (https://en.wikipedia.org/wiki/IPv4#Special_addresses) are always imported to peers and are not controlled by this field.
state: StateOutput only. State of the network peering. This field has a value of ‘ACTIVE’ when there’s a matching configuration in the peer network. New values may be added to this enum when appropriate.
state_details: StringOutput only. Output Only. Details about the current state of the network peering.
peer_mtu: i32Optional. Maximum transmission unit (MTU) in bytes.
The default value is 1500. If a value of 0 is provided for this field,
VMware Engine uses the default value instead.
peer_network_type: PeerNetworkTypeRequired. The type of the network to peer with the VMware Engine network.
uid: StringOutput only. System-generated unique identifier for the resource.
vmware_engine_network: StringRequired. The relative resource name of the VMware Engine network.
Specify the name in the following form:
projects/{project}/locations/{location}/vmwareEngineNetworks/{vmware_engine_network_id}
where {project} can either be a project number or a project ID.
description: StringOptional. User-provided description for this network peering.
Implementations
Sourceimpl NetworkPeering
impl NetworkPeering
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = NetworkPeering::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = NetworkPeering::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = NetworkPeering::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = NetworkPeering::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = NetworkPeering::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = NetworkPeering::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_peer_network<T: Into<String>>(self, v: T) -> Self
pub fn set_peer_network<T: Into<String>>(self, v: T) -> Self
Sets the value of peer_network.
Example
let x = NetworkPeering::new().set_peer_network("example");Sourcepub fn set_export_custom_routes<T>(self, v: T) -> Self
pub fn set_export_custom_routes<T>(self, v: T) -> Self
Sets the value of export_custom_routes.
Example
let x = NetworkPeering::new().set_export_custom_routes(true);Sourcepub fn set_or_clear_export_custom_routes<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_export_custom_routes<T>(self, v: Option<T>) -> Self
Sets or clears the value of export_custom_routes.
Example
let x = NetworkPeering::new().set_or_clear_export_custom_routes(Some(false));
let x = NetworkPeering::new().set_or_clear_export_custom_routes(None::<bool>);Sourcepub fn set_import_custom_routes<T>(self, v: T) -> Self
pub fn set_import_custom_routes<T>(self, v: T) -> Self
Sets the value of import_custom_routes.
Example
let x = NetworkPeering::new().set_import_custom_routes(true);Sourcepub fn set_or_clear_import_custom_routes<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_import_custom_routes<T>(self, v: Option<T>) -> Self
Sets or clears the value of import_custom_routes.
Example
let x = NetworkPeering::new().set_or_clear_import_custom_routes(Some(false));
let x = NetworkPeering::new().set_or_clear_import_custom_routes(None::<bool>);Sourcepub fn set_exchange_subnet_routes<T>(self, v: T) -> Self
pub fn set_exchange_subnet_routes<T>(self, v: T) -> Self
Sets the value of exchange_subnet_routes.
Example
let x = NetworkPeering::new().set_exchange_subnet_routes(true);Sourcepub fn set_or_clear_exchange_subnet_routes<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_exchange_subnet_routes<T>(self, v: Option<T>) -> Self
Sets or clears the value of exchange_subnet_routes.
Example
let x = NetworkPeering::new().set_or_clear_exchange_subnet_routes(Some(false));
let x = NetworkPeering::new().set_or_clear_exchange_subnet_routes(None::<bool>);Sourcepub fn set_export_custom_routes_with_public_ip<T>(self, v: T) -> Self
pub fn set_export_custom_routes_with_public_ip<T>(self, v: T) -> Self
Sets the value of export_custom_routes_with_public_ip.
Example
let x = NetworkPeering::new().set_export_custom_routes_with_public_ip(true);Sourcepub fn set_or_clear_export_custom_routes_with_public_ip<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_export_custom_routes_with_public_ip<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of export_custom_routes_with_public_ip.
Example
let x = NetworkPeering::new().set_or_clear_export_custom_routes_with_public_ip(Some(false));
let x = NetworkPeering::new().set_or_clear_export_custom_routes_with_public_ip(None::<bool>);Sourcepub fn set_import_custom_routes_with_public_ip<T>(self, v: T) -> Self
pub fn set_import_custom_routes_with_public_ip<T>(self, v: T) -> Self
Sets the value of import_custom_routes_with_public_ip.
Example
let x = NetworkPeering::new().set_import_custom_routes_with_public_ip(true);Sourcepub fn set_or_clear_import_custom_routes_with_public_ip<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_import_custom_routes_with_public_ip<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of import_custom_routes_with_public_ip.
Example
let x = NetworkPeering::new().set_or_clear_import_custom_routes_with_public_ip(Some(false));
let x = NetworkPeering::new().set_or_clear_import_custom_routes_with_public_ip(None::<bool>);Sourcepub fn set_state_details<T: Into<String>>(self, v: T) -> Self
pub fn set_state_details<T: Into<String>>(self, v: T) -> Self
Sets the value of state_details.
Example
let x = NetworkPeering::new().set_state_details("example");Sourcepub fn set_peer_mtu<T: Into<i32>>(self, v: T) -> Self
pub fn set_peer_mtu<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_peer_network_type<T: Into<PeerNetworkType>>(self, v: T) -> Self
pub fn set_peer_network_type<T: Into<PeerNetworkType>>(self, v: T) -> Self
Sets the value of peer_network_type.
Example
use google_cloud_vmwareengine_v1::model::network_peering::PeerNetworkType;
let x0 = NetworkPeering::new().set_peer_network_type(PeerNetworkType::Standard);
let x1 = NetworkPeering::new().set_peer_network_type(PeerNetworkType::VmwareEngineNetwork);
let x2 = NetworkPeering::new().set_peer_network_type(PeerNetworkType::PrivateServicesAccess);Sourcepub fn set_vmware_engine_network<T: Into<String>>(self, v: T) -> Self
pub fn set_vmware_engine_network<T: Into<String>>(self, v: T) -> Self
Sets the value of vmware_engine_network.
Example
let x = NetworkPeering::new().set_vmware_engine_network(format!("projects/{project_id}/locations/{location_id}/vmwareEngineNetworks/{vmware_engine_network_id}"));Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self