#[non_exhaustive]pub struct NodeType {
pub name: String,
pub node_type_id: String,
pub display_name: String,
pub virtual_cpu_count: i32,
pub total_core_count: i32,
pub memory_gb: i32,
pub disk_size_gb: i32,
pub available_custom_core_counts: Vec<i32>,
pub kind: Kind,
pub families: Vec<String>,
pub capabilities: Vec<Capability>,
/* private fields */
}Expand description
Describes node type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of this node type.
Resource names are schemeless URIs that follow the conventions in
https://cloud.google.com/apis/design/resource_names.
For example:
projects/my-proj/locations/us-central1-a/nodeTypes/standard-72
node_type_id: StringOutput only. The canonical identifier of the node type
(corresponds to the NodeType). For example: standard-72.
display_name: StringOutput only. The friendly name for this node type. For example: ve1-standard-72
virtual_cpu_count: i32Output only. The total number of virtual CPUs in a single node.
total_core_count: i32Output only. The total number of CPU cores in a single node.
memory_gb: i32Output only. The amount of physical memory available, defined in GB.
disk_size_gb: i32Output only. The amount of storage available, defined in GB.
available_custom_core_counts: Vec<i32>Output only. List of possible values of custom core count.
kind: KindOutput only. The type of the resource.
families: Vec<String>Output only. Families of the node type.
For node types to be in the same cluster
they must share at least one element in the families.
capabilities: Vec<Capability>Output only. Capabilities of this node type.
Implementations
Sourceimpl NodeType
impl NodeType
Sourcepub fn set_node_type_id<T: Into<String>>(self, v: T) -> Self
pub fn set_node_type_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_virtual_cpu_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_virtual_cpu_count<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_total_core_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_total_core_count<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_memory_gb<T: Into<i32>>(self, v: T) -> Self
pub fn set_memory_gb<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_disk_size_gb<T: Into<i32>>(self, v: T) -> Self
pub fn set_disk_size_gb<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_available_custom_core_counts<T, V>(self, v: T) -> Self
pub fn set_available_custom_core_counts<T, V>(self, v: T) -> Self
Sets the value of available_custom_core_counts.
Example
let x = NodeType::new().set_available_custom_core_counts([1, 2, 3]);Sourcepub fn set_families<T, V>(self, v: T) -> Self
pub fn set_families<T, V>(self, v: T) -> Self
Sourcepub fn set_capabilities<T, V>(self, v: T) -> Self
pub fn set_capabilities<T, V>(self, v: T) -> Self
Sets the value of capabilities.
Example
use google_cloud_vmwareengine_v1::model::node_type::Capability;
let x = NodeType::new().set_capabilities([
Capability::StretchedClusters,
]);Trait Implementations
impl StructuralPartialEq for NodeType