#[non_exhaustive]pub struct PeeringRoute {
pub dest_range: String,
pub type: Type,
pub next_hop_region: String,
pub priority: i64,
pub imported: bool,
pub direction: Direction,
/* private fields */
}Expand description
Exchanged network peering route.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dest_range: StringOutput only. Destination range of the peering route in CIDR notation.
type: TypeOutput only. Type of the route in the peer VPC network.
next_hop_region: StringOutput only. Region containing the next hop of the peering route. This field only applies to dynamic routes in the peer VPC network.
priority: i64Output only. The priority of the peering route.
imported: boolOutput only. True if the peering route has been imported from a peered
VPC network; false otherwise. The import happens if the field
NetworkPeering.importCustomRoutes is true for this network,
NetworkPeering.exportCustomRoutes is true for the peer VPC network, and
the import does not result in a route conflict.
direction: DirectionOutput only. Direction of the routes exchanged with the peer network, from the VMware Engine network perspective:
- Routes of direction
INCOMINGare imported from the peer network. - Routes of direction
OUTGOINGare exported from the intranet VPC network of the VMware Engine network.
Implementations
Sourceimpl PeeringRoute
impl PeeringRoute
Sourcepub fn set_dest_range<T: Into<String>>(self, v: T) -> Self
pub fn set_dest_range<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_next_hop_region<T: Into<String>>(self, v: T) -> Self
pub fn set_next_hop_region<T: Into<String>>(self, v: T) -> Self
Sets the value of next_hop_region.
Example
let x = PeeringRoute::new().set_next_hop_region("example");Sourcepub fn set_priority<T: Into<i64>>(self, v: T) -> Self
pub fn set_priority<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_imported<T: Into<bool>>(self, v: T) -> Self
pub fn set_imported<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_direction<T: Into<Direction>>(self, v: T) -> Self
pub fn set_direction<T: Into<Direction>>(self, v: T) -> Self