#[non_exhaustive]pub struct ResetNsxCredentialsRequest {
pub private_cloud: String,
pub request_id: String,
/* private fields */
}Expand description
Request message for VmwareEngine.ResetNsxCredentials
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.private_cloud: StringRequired. The resource name of the private cloud
to reset credentials for.
Resource names are schemeless URIs that follow the conventions in
https://cloud.google.com/apis/design/resource_names.
For example:
projects/my-project/locations/us-central1-a/privateClouds/my-cloud
request_id: StringOptional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server guarantees that a request doesn’t result in creation of duplicate commitments for at least 60 minutes.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl ResetNsxCredentialsRequest
impl ResetNsxCredentialsRequest
Sourcepub fn set_private_cloud<T: Into<String>>(self, v: T) -> Self
pub fn set_private_cloud<T: Into<String>>(self, v: T) -> Self
Sets the value of private_cloud.
Example
let x = ResetNsxCredentialsRequest::new().set_private_cloud(format!("projects/{project_id}/locations/{location_id}/privateClouds/{private_cloud_id}"));Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = ResetNsxCredentialsRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for ResetNsxCredentialsRequest
impl Clone for ResetNsxCredentialsRequest
Sourcefn clone(&self) -> ResetNsxCredentialsRequest
fn clone(&self) -> ResetNsxCredentialsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ResetNsxCredentialsRequest
impl Debug for ResetNsxCredentialsRequest
Sourceimpl Default for ResetNsxCredentialsRequest
impl Default for ResetNsxCredentialsRequest
Sourcefn default() -> ResetNsxCredentialsRequest
fn default() -> ResetNsxCredentialsRequest
Sourceimpl Message for ResetNsxCredentialsRequest
impl Message for ResetNsxCredentialsRequest
impl StructuralPartialEq for ResetNsxCredentialsRequest