#[non_exhaustive]pub struct VmwareEngineNetwork {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub description: String,
pub vpc_networks: Vec<VpcNetwork>,
pub state: State,
pub type: Type,
pub uid: String,
pub etag: String,
/* private fields */
}Expand description
VMware Engine network resource that provides connectivity for VMware Engine private clouds.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of the VMware Engine network.
Resource names are schemeless URIs that follow the conventions in
https://cloud.google.com/apis/design/resource_names.
For example:
projects/my-project/locations/global/vmwareEngineNetworks/my-network
create_time: Option<Timestamp>Output only. Creation time of this resource.
update_time: Option<Timestamp>Output only. Last update time of this resource.
description: StringUser-provided description for this VMware Engine network.
vpc_networks: Vec<VpcNetwork>Output only. VMware Engine service VPC networks that provide connectivity from a private cloud to customer projects, the internet, and other Google Cloud services.
state: StateOutput only. State of the VMware Engine network.
type: TypeRequired. VMware Engine network type.
uid: StringOutput only. System-generated unique identifier for the resource.
etag: StringChecksum that may be sent on update and delete requests to ensure that the user-provided value is up to date before the server processes a request. The server computes checksums based on the value of other fields in the request.
Implementations
Sourceimpl VmwareEngineNetwork
impl VmwareEngineNetwork
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = VmwareEngineNetwork::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = VmwareEngineNetwork::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = VmwareEngineNetwork::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = VmwareEngineNetwork::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = VmwareEngineNetwork::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = VmwareEngineNetwork::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = VmwareEngineNetwork::new().set_description("example");Sourcepub fn set_vpc_networks<T, V>(self, v: T) -> Self
pub fn set_vpc_networks<T, V>(self, v: T) -> Self
Sets the value of vpc_networks.
Example
use google_cloud_vmwareengine_v1::model::vmware_engine_network::VpcNetwork;
let x = VmwareEngineNetwork::new()
.set_vpc_networks([
VpcNetwork::default()/* use setters */,
VpcNetwork::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for VmwareEngineNetwork
impl Clone for VmwareEngineNetwork
Sourcefn clone(&self) -> VmwareEngineNetwork
fn clone(&self) -> VmwareEngineNetwork
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for VmwareEngineNetwork
impl Debug for VmwareEngineNetwork
Sourceimpl Default for VmwareEngineNetwork
impl Default for VmwareEngineNetwork
Sourcefn default() -> VmwareEngineNetwork
fn default() -> VmwareEngineNetwork
Sourceimpl Message for VmwareEngineNetwork
impl Message for VmwareEngineNetwork
Sourceimpl PartialEq for VmwareEngineNetwork
impl PartialEq for VmwareEngineNetwork
impl StructuralPartialEq for VmwareEngineNetwork